.. ui.cmdline.core.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive._ui._cmdline._core package.



AutoArchive._ui._cmdline._core
==============================

.. automodule:: AutoArchive._ui._cmdline._core
   :no-members:



Modules
-------

cmdline_ui_component
^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._ui._cmdline._core.cmdline_ui_component



_user_action_executor
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._ui._cmdline._core._user_action_executor
.. autoclass:: _UserActionExecutor
